==> joynr-1.21.4.tgz: package/global/WebSocketNode.js <==
"use strict";
/*
 * #%L
 * %%
 * Copyright (C) 2011 - 2017 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
/**
 * Adapts the nodejs websocket lib WebSocket-Node to the WebSocket client API.
 * See: http://dev.w3.org/html5/websockets/#the-websocket-interface
 *
 */
const ws_1 = __importDefault(require("ws"));
class WebSocketNode extends ws_1.default {
    constructor(remoteUrl, keychain, useUnencryptedTls) {
        const clientOptions = {};
        if (keychain) {
            clientOptions.cert = keychain.tlsCert;
            clientOptions.key = keychain.tlsKey;
            clientOptions.ca = keychain.tlsCa;
            clientOptions.rejectUnauthorized = true;
            clientOptions.checkServerIdentity = keychain.checkServerIdentity;
        }
        if (useUnencryptedTls) {
            clientOptions.ciphers = "eNULL:@SECLEVEL=0";
        }
        super(remoteUrl, clientOptions);
    }
}
WebSocketNode.WSN_CONNECTING = ws_1.default.CONNECTING;
WebSocketNode.WSN_OPEN = ws_1.default.OPEN;
WebSocketNode.WSN_CLOSING = ws_1.default.CLOSING;
WebSocketNode.WSN_CLOSED = ws_1.default.CLOSED;
module.exports = WebSocketNode;

==> joynr-1.21.7.tgz: package/global/WebSocketNode.js <==
"use strict";
/*
 * #%L
 * %%
 * Copyright (C) 2011 - 2017 BMW Car IT GmbH
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
/**
 * Adapts the nodejs websocket lib WebSocket-Node to the WebSocket client API.
 * See: http://dev.w3.org/html5/websockets/#the-websocket-interface
 *
 */
const ws_1 = __importDefault(require("ws"));
class WebSocketNode extends ws_1.default {
    constructor(remoteUrl, keychain) {
        const clientOptions = {};
        if (keychain) {
            clientOptions.cert = keychain.tlsCert;
            clientOptions.key = keychain.tlsKey;
            clientOptions.ca = keychain.tlsCa;
            clientOptions.rejectUnauthorized = true;
            clientOptions.checkServerIdentity = keychain.checkServerIdentity;
        }
        super(remoteUrl, clientOptions);
    }
}
WebSocketNode.WSN_CONNECTING = ws_1.default.CONNECTING;
WebSocketNode.WSN_OPEN = ws_1.default.OPEN;
WebSocketNode.WSN_CLOSING = ws_1.default.CLOSING;
WebSocketNode.WSN_CLOSED = ws_1.default.CLOSED;
module.exports = WebSocketNode;
